@@ -1,7 +1,4 @@
-from sqlalchemy import Column
-from sqlalchemy import ForeignKey
-from sqlalchemy import Integer
-from sqlalchemy import String
+from sqlalchemy import Column, ForeignKey, Integer, String, DateTime
 from sqlalchemy.orm import relationship
 from sqlalchemy.schema import UniqueConstraint
 
@@ -16,14 +13,18 @@ class Message(OKCBase):
         UniqueConstraint('message_thread_id', 'thread_index'),
     )
 
+    time_sent = Column(DateTime, nullable=True)
+
     message_thread_id = Column(Integer, ForeignKey("message_thread.id"),
                                nullable=False)
 
     sender_id = Column(Integer, ForeignKey("user.id"))
-    sender = relationship("User", foreign_keys=[sender_id])
+    sender = relationship("User", foreign_keys=[sender_id],
+                          backref='sent_messages')
 
     recipient_id = Column(Integer, ForeignKey("user.id"))
-    recipient = relationship("User", foreign_keys=[recipient_id])
+    recipient = relationship("User", foreign_keys=[recipient_id],
+                             backref='received_messages')
 
     text = Column(String, nullable=False)
     thread_index = Column(Integer, nullable=False)
